@@ -23,8 +23,8 @@
 #include "config.h"
 
 #include "ephy-notebook.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
+#include "ephy-settings.h"
 #include "ephy-marshal.h"
 #include "ephy-file-helpers.h"
 #include "ephy-dnd.h"
@@ -46,7 +46,7 @@
 
 #define INSANE_NUMBER_OF_URLS 20
 
-#define EPHY_NOTEBOOK_TAB_GROUP_ID (GUINT_TO_POINTER (42))
+#define EPHY_NOTEBOOK_TAB_GROUP_ID "0x42"
 
 #define EPHY_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NOTEBOOK, EphyNotebookPrivate))
 
@@ -371,7 +371,8 @@ notebook_drag_data_received_cb (GtkWidget* widget,
 
 	g_signal_stop_emission_by_name (widget, "drag_data_received");
 
-	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL)) return;
+	if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
+				    EPHY_PREFS_LOCKDOWN_ARBITRARY_URL)) return;
 
 	data = gtk_selection_data_get_data (selection_data);
 	if (gtk_selection_data_get_length (selection_data) <= 0 || data == NULL) return;
@@ -437,17 +438,18 @@ update_tabs_visibility (EphyNotebook *nb,
 
 	if (before_inserting) num++;
 
-	show_tabs = (eel_gconf_get_boolean (CONF_ALWAYS_SHOW_TABS_BAR) || num > 1) &&
+	show_tabs = (g_settings_get_boolean (EPHY_SETTINGS_UI,
+					     EPHY_PREFS_UI_ALWAYS_SHOW_TABS_BAR)
+		     || num > 1) &&
 		    priv->show_tabs == TRUE;
 
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
 }
 
 static void
-tabs_visibility_notifier (GConfClient *client,
-			  guint cnxn_id,
-			  GConfEntry *entry,
-			  EphyNotebook *nb)
+show_tabs_changed_cb (GSettings *settings,
+		      char *key,
+		      EphyNotebook *nb)
 {
 	update_tabs_visibility (nb, FALSE);
 }
@@ -464,7 +466,7 @@ ephy_notebook_init (EphyNotebook *notebook)
 	gtk_notebook_set_scrollable (gnotebook, TRUE);
 	gtk_notebook_set_show_border (gnotebook, FALSE);
 	gtk_notebook_set_show_tabs (gnotebook, FALSE);
-        gtk_notebook_set_group (gnotebook, EPHY_NOTEBOOK_TAB_GROUP_ID);
+	gtk_notebook_set_group_name (gnotebook, EPHY_NOTEBOOK_TAB_GROUP_ID);
 
 	priv->show_tabs = TRUE;
 	priv->dnd_enabled = TRUE;
@@ -484,9 +486,9 @@ ephy_notebook_init (EphyNotebook *notebook)
 			   GDK_ACTION_MOVE | GDK_ACTION_COPY);
 	gtk_drag_dest_add_text_targets (widget);
 
-	priv->tabs_vis_notifier_id = eel_gconf_notification_add
-		(CONF_ALWAYS_SHOW_TABS_BAR,
-		 (GConfClientNotifyFunc)tabs_visibility_notifier, notebook);
+	g_signal_connect (EPHY_SETTINGS_UI,
+			  "changed::" EPHY_PREFS_UI_ALWAYS_SHOW_TABS_BAR,
+			  G_CALLBACK (show_tabs_changed_cb), notebook);
 }
 
 static void
@@ -495,8 +497,6 @@ ephy_notebook_finalize (GObject *object)
 	EphyNotebook *notebook = EPHY_NOTEBOOK (object);
 	EphyNotebookPrivate *priv = notebook->priv;
 
-	eel_gconf_notification_remove (priv->tabs_vis_notifier_id);
-
 	g_list_free (priv->focused_pages);
 
 	G_OBJECT_CLASS (ephy_notebook_parent_class)->finalize (object);
